#  docutools

<p attr="autogenerated by make_badges"></p>

[![docs][img_docs]][lnk_docs]&nbsp; [![package][img_package]][lnk_package]&nbsp; [![discuss][img_discuss]][lnk_discuss]&nbsp; [![pipeline][img_pipeline]][lnk_pipeline]&nbsp; [![coverage][img_coverage]][lnk_coverage]&nbsp; [![statements][img_statements]][lnk_statements]&nbsp; [![code style][img_code style]][lnk_code style]

[lnk_docs]: http://github.pages.com/docutools/
[img_docs]: https://badges.github.com/scm/hg/noauth/badges/raw-file/62eef82452cb/docutools/documentation.svg
[lnk_package]: https://artifacts.github.com/artifactory/pypi-ax-sources/docutools/2021.1.21.dev14+g13aab44.d20210418/docutools-2021.1.21.dev14+g13aab44.d20210418.tar.gz
[img_package]: https://badges.github.com/scm/hg/noauth/badges/raw-file/62eef82452cb/docutools/pypi_package.svg
[lnk_discuss]: https://join.skype.com/krSNYZqvEmJm
[img_discuss]: https://badges.github.com/scm/hg/noauth/badges/raw-file/62eef82452cb/docutools/discuss.svg
[lnk_pipeline]: https://axiros.github.com/devapps/docutools/-/commits/master
[img_pipeline]: https://badges.github.com/scm/hg/noauth/badges/raw-file/62eef82452cb/docutools/pipeline.svg
[lnk_coverage]: http://github.pages.com/docutools//coverage/index.html
[img_coverage]: https://badges.github.com/scm/hg/noauth/badges/raw-file/62eef82452cb/docutools/coverage.svg
[lnk_statements]: http://github.pages.com/docutools//coverage/index.html
[img_statements]: https://badges.github.com/scm/hg/noauth/badges/raw-file/62eef82452cb/docutools/statements.svg
[lnk_code style]: https://github.com/axiros/axblack
[img_code style]: https://badges.github.com/scm/hg/noauth/badges/raw-file/62eef82452cb/docutools/code_style_ax_black.svg

<p attr="autogenerated by make_badges"></p>

## Documentation building tools

!!! caution "Work in Progress"
    The termcast feature is heavily W.I.P!


![](img/page-teaser.png){: style="width:1550px" }

This library is meant to be used as a development dependency for projects which want [mkdocs/material](https://squidfunk.github.io/mkdocs-material/) based documentation,
pulling in all the necessary dependencies plus adding a few strong features as well, which were to hard / did not make sense to realize as mkdocs plugins.






<!-- pre_proc_marker -->


----


Last modified: Fri Jul 30 11:05:34 2021